@@ -1,7 +1,6 @@
-pub mod tsfile_search_reader;
-pub mod reader;
+pub mod compress;
 pub mod footer;
 pub mod metadata;
-mod statistics;
-
-
+pub mod reader;
+pub mod statistics;
+pub mod tsfile_search_reader;
